from microbit import *
from time import sleep_us
import time


# 定义LCD各引脚连接到micro:bit的哪个引脚
RS = pin8
EN = pin2
D4 = pin16
D5 = pin15
D6 = pin14
D7 = pin13

# 初始化LCD
def init_lcd():
    # 初始化LCD的各个引脚
    RS.write_digital(0)
    EN.write_digital(0)
    D4.write_digital(0)
    D5.write_digital(0)
    D6.write_digital(0)
    D7.write_digital(0)
    # 初始化过程
    send_cmd(0x33)  # 初始化
    send_cmd(0x32)  # 初始化
    send_cmd(0x28)  # 4位，2行，5x8
    send_cmd(0x0C)  # 显示开，无光标，不闪烁
    send_cmd(0x06)  # 光标右移，字符不移动
    send_cmd(0x01)  # 清屏

# 发送命令到LCD
def send_cmd(cmd):
    RS.write_digital(0)  # 告诉LCD这是命令
    EN.write_digital(0)  # 使能引脚置为0
    # 发送高4位
    D4.write_digital((cmd >> 4) & 1)
    D5.write_digital((cmd >> 5) & 1)
    D6.write_digital((cmd >> 6) & 1)
    D7.write_digital((cmd >> 7) & 1)
    EN.write_digital(1)  # 使能引脚置为1
    EN.write_digital(0)  # 使能引脚置为0
    # 发送低4位
    D4.write_digital(cmd & 1)
    D5.write_digital((cmd >> 1) & 1)
    D6.write_digital((cmd >> 2) & 1)
    D7.write_digital((cmd >> 3) & 1)
    EN.write_digital(1)  # 使能引脚置为1
    EN.write_digital(0)  # 使能引脚置为0

# 发送数据到LCD
def send_data(data):
    RS.write_digital(1)  # 告诉LCD这是数据
    EN.write_digital(0)  # 使能引脚置为0
    # 发送高4位
    D4.write_digital((data >> 4) & 1)
    D5.write_digital((data >> 5) & 1)
    D6.write_digital((data >> 6) & 1)
    D7.write_digital((data >> 7) & 1)
    EN.write_digital(1)  # 使能引脚置为1
    EN.write_digital(0)  # 使能引脚置为0
    # 发送低4位
    D4.write_digital(data & 1)
    D5.write_digital((data >> 1) & 1)
    D6.write_digital((data >> 2) & 1)
    D7.write_digital((data >> 3) & 1)
    EN.write_digital(1)  # 使能引脚置为1
    EN.write_digital(0)  # 使能引脚置为0

# 在LCD上显示字符
def show_text(text):
    for char in text:
        send_data(ord(char))
        sleep_us(5)

# 初始化LCD
init_lcd()

# 在LCD上显示“HELLO WORLD”
show_text("HELLO WORLD")